@@ -1,12 +1,12 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.27 2004/12/14 05:09:29 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.29 2005/01/05 13:27:20 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003, 2004	Tatsuo Ishii
+ * Copyright (c) 2003-2005	Tatsuo Ishii
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -31,13 +31,6 @@
 #include <stdio.h>
 #include <time.h>
 
-/* 
- * define this if you do not want to issue RESET ALL at each new
- * connection.  Also you need to define this for 7.1 or prior
- * PostgreSQL since they do not support RESET ALL
- */
-#undef NO_RESET_ALL
-
 /* undef this if you have problems with non blocking accept() */
 #define NONE_BLOCK
 
@@ -138,14 +131,16 @@ typedef struct {
 
 	int load_balance_mode;		/* load balance mode */
 
-	/* followings do not exist in the configuration file */
-    char	*current_backend_host_name;	/* current backend host name */
-    int	current_backend_port;	/* current backend port # */
-	int replication_enabled;		/* replication mode enabled */
-
 	int replication_stop_on_mismatch;		/* if there's a data mismatch between master and secondary
 											 * start degenration to stop replication mode
 											 */
+	char **reset_query_list;		/* comma separated list of quries to be issued at the end of session */
+
+	/* followings do not exist in the configuration file */
+    char *current_backend_host_name;	/* current backend host name */
+    int	current_backend_port;	/* current backend port # */
+	int replication_enabled;		/* replication mode enabled */
+	int num_reset_queries;		/* number of queries in reset_query_list */
 } POOL_CONFIG;
 
 #define MAX_PASSWORD_SIZE		1024
